==> zeroconf-0.1.1.tgz: zeroconf-0.1.1/php_zeroconf.h <==
/* ==================================================================
 * ZeroConf Extension for PHP
 * Copyright (c) 2004 Gabriel Ricard
 * All rights reserved.
 * ==================================================================
 * This source code is made available free and without charge subject
 * to the terms of the PHP Group License as detailed in bundled LICENSE file.
 * ==================================================================
 * Gabriel Ricard <gabe@php.net>
 * ==================================================================
 */

#ifndef PHP_ZEROCONF_H
#define PHP_ZEROCONF_H

extern zend_module_entry zeroconf_module_entry;
#define phpext_zeroconf_ptr &zeroconf_module_entry

#ifdef PHP_WIN32
#define PHP_ZEROCONF_API __declspec(dllexport)
#else
#define PHP_ZEROCONF_API
#endif

#ifdef ZTS
#include "TSRM.h"
#endif

PHP_MINIT_FUNCTION(zeroconf);
PHP_MSHUTDOWN_FUNCTION(zeroconf);
PHP_RINIT_FUNCTION(zeroconf);
PHP_RSHUTDOWN_FUNCTION(zeroconf);
PHP_MINFO_FUNCTION(zeroconf);

PHP_FUNCTION(zeroconf_session_init);
PHP_FUNCTION(zeroconf_browse_service);
PHP_FUNCTION(zeroconf_browse_process);
PHP_FUNCTION(zeroconf_session_destroy);

/* 
  	Declare any global variables you may need between the BEGIN
	and END macros here:     

ZEND_BEGIN_MODULE_GLOBALS(zeroconf)
	long  global_value;
	char *global_string;
ZEND_END_MODULE_GLOBALS(zeroconf)
*/

/* In every utility function you add that needs to use variables 
   in php_zeroconf_globals, call TSRMLS_FETCH(); after declaring other 
   variables used by that function, or better yet, pass in TSRMLS_CC
   after the last function argument and declare your utility function
   with TSRMLS_DC after the last declared argument.  Always refer to
   the globals in your function as ZEROCONF_G(variable).  You are 
   encouraged to rename these macros something shorter, see
   examples in any other php module directory.
*/

#ifdef ZTS
#define ZEROCONF_G(v) TSRMG(zeroconf_globals_id, zend_zeroconf_globals *, v)
#else
#define ZEROCONF_G(v) (zeroconf_globals.v)
#endif

#endif	/* PHP_ZEROCONF_H */


/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * indent-tabs-mode: t
 * End:
 */

==> zeroconf-0.1.2.tgz: zeroconf-0.1.2/php_zeroconf.h <==
/* ==================================================================
 * ZeroConf Extension for PHP
 * Copyright (c) 2004 Gabriel Ricard
 * All rights reserved.
 * ==================================================================
 * This source code is made available free and without charge subject
 * to the terms of the PHP Group License as detailed in bundled LICENSE file.
 * ==================================================================
 * Original Code by:
 * Gabriel Ricard <gabe@php.net>
 * port to apple zeroconf library by:
 * John LeSueur <jlesueur@php.net>
 * ==================================================================
 */

#ifndef PHP_ZEROCONF_H
#define PHP_ZEROCONF_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <php.h>
#include <php_ini.h>
#include <SAPI.h>
#include <ext/standard/info.h>

#include <dns_sd.h>
#include <arpa/nameser.h>

extern zend_module_entry zeroconf_module_entry;
#define phpext_zeroconf_ptr &zeroconf_module_entry

#ifdef PHP_WIN32
#define PHP_ZEROCONF_API __declspec(dllexport)
#else
#define PHP_ZEROCONF_API
#endif

PHP_MINIT_FUNCTION(zeroconf);
PHP_MSHUTDOWN_FUNCTION(zeroconf);
PHP_RINIT_FUNCTION(zeroconf);
PHP_RSHUTDOWN_FUNCTION(zeroconf);
PHP_MINFO_FUNCTION(zeroconf);

#ifdef ZTS
#include "TSRM.h"
#endif


PHP_FUNCTION(zeroconf_register_service);
PHP_FUNCTION(zeroconf_browse_service);
PHP_FUNCTION(zeroconf_get_all_services);
PHP_FUNCTION(zeroconf_browse_session_create);
PHP_FUNCTION(zeroconf_browse_session_process);

typedef struct timeval timeval;

typedef struct 
{
	DNSServiceRef ref;
	zval * callback;
} zeroconf_browse_session;

/* 
  	Declare any global variables you may need between the BEGIN
	and END macros here:     

ZEND_BEGIN_MODULE_GLOBALS(zeroconf)
	long  global_value;
	char *global_string;
ZEND_END_MODULE_GLOBALS(zeroconf)
*/

/* In every utility function you add that needs to use variables 
   in php_zeroconf_globals, call TSRMLS_FETCH(); after declaring other 
   variables used by that function, or better yet, pass in TSRMLS_CC
   after the last function argument and declare your utility function
   with TSRMLS_DC after the last declared argument.  Always refer to
   the globals in your function as ZEROCONF_G(variable).  You are 
   encouraged to rename these macros something shorter, see
   examples in any other php module directory.
*/

#ifdef ZTS
#define ZEROCONF_G(v) TSRMG(zeroconf_globals_id, zend_zeroconf_globals *, v)
#else
#define ZEROCONF_G(v) (zeroconf_globals.v)
#endif

#endif	/* PHP_ZEROCONF_H */


/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * indent-tabs-mode: t
 * End:
 */
